import * as React from "react";
import Highlighter from "react-highlight-words";
import terms from "./terms.json";
import { KeyTerm } from "./KeyTerm";

export const HighlightKeyTerms: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  return (
    <>
      {React.Children.map(children, (child) => {
        if (typeof child !== "string") {
          return child;
        }

        return (
          <Highlighter
            searchWords={Object.keys(terms)}
            textToHighlight={child}
            findChunks={({ searchWords, textToHighlight }) => {
              const chunks = [];

              for (const word of searchWords) {
                if (typeof word !== "string") {
                  continue;
                }

                if (!word.length) {
                  continue;
                }

                const index = textToHighlight
                  .toLowerCase()
                  .indexOf(word.toLowerCase());

                if (index > -1) {
                  chunks.push({
                    start: index,
                    end: index + word.length,
                  });
                }
              }

              return chunks;
            }}
            highlightTag={({ children }) => {
              const { definition } =
                terms[children.toLowerCase() as keyof typeof terms];

              if (!definition) {
                return null;
              }

              return <KeyTerm term={children} definition={definition} />;
            }}
          />
        );
      })}
    </>
  );
};
