import fs from "fs";
import path from "path";
import { stringify } from "gray-matter";

try {
  const rawTerms = fs.readFileSync(
    path.join(__dirname, "raw-terms.json"),
    "utf-8"
  );

  const entries = JSON.parse(rawTerms);

  // Check if the input is an array
  if (!Array.isArray(entries)) {
    throw new Error("Input JSON must be an array.");
  }

  // Process each object in the array
  for (const entry of entries) {
    const { term, shortDefinition, ...frontmatter } = entry;

    const content = stringify(shortDefinition, frontmatter);

    const filename = `${encodeURIComponent(term)}.md`;
    const filePath = path.join(__dirname, "terms", filename);
    fs.writeFileSync(filePath, content, "utf-8");
    console.log(`Markdown file (${filename}) generated successfully!`);
  }
} catch (error) {
  console.error("Error processing JSON:", error.message);
}
